<?php
require_once 'util/Logger.php';

class RemoteAlarmingAsync implements AlarmingInterface {

	static public function processAlarm (
			InstAddr   $inst_addr,		  // instance address
			$evt_time,					  // event time
			EventSpec  $evt_spec,		  // event specification
			ServInfl   $serv_infl = null, // service influence
			AlarmSevty $perc_sev  = null, // perceived severity
			$src_host_name = null,				// source host name (local if null)
			HostAddr   $src_host_addr = null,	// source host address 
			HostAddr   $tgt_host_addr = null	// target host address 
			) {
				
		// check input		
		if ($tgt_host_addr == null) throw new Exception("no remote host given");
		
		$logger = Logger::getInstance();
		try {
			// create SOAP client
			$host = $tgt_host_addr->getValue();
			$soap_client = new SoapClient(
				"http://localhost/sysal/soap/service.php?class=SoapAlarming&wsdl",
				array("location" => "http://$host/sysal/soap/service.php?class=SoapAlarming")
			); 
			
			$logger->log(__FILE__, "Calling soap client.processAlarmAsync:");
			$logger->log(__FILE__, "  instance address   : $inst_addr");
			$logger->log(__FILE__, "  event time         : $evt_time");
			$logger->log(__FILE__, "  event specification: $evt_spec");
			$logger->log(__FILE__, "  service influence  : $serv_infl");
			$logger->log(__FILE__, "  perceived severity : $perc_sev");
			$logger->log(__FILE__, "  source host name   : $src_host_name");
			$logger->log(__FILE__, "  source host address: $src_host_addr");
			
			$ret = $soap_client->processAlarmAsync(
				$inst_addr,		  // instance address
				$evt_time,					  // event time
				$evt_spec,		  // event specification
				$serv_infl, // service influence
				$perc_sev, // perceived severity
				$src_host_name,				// source host name (local if null)
				$src_host_addr	// source host address 
			);
			if ($ret != 0) throw new Exception("processAlarmAsync failed: $ret");
		}
		catch(Exception $e) {
			// alarm processing must not die du to problems with remote host
			$logger->logException(__CLASS__, $e);
		}
	}
}
